@@ -17,11 +17,11 @@ HTTP::Proxy::GreaseMonkey::Redirector - Proxy cross-site requests
 
 =head1 VERSION
 
-This document describes HTTP::Proxy::GreaseMonkey::Redirector version 0.04
+This document describes HTTP::Proxy::GreaseMonkey::Redirector version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 =head1 SYNOPSIS
   
@@ -144,7 +144,7 @@ sub _despatch_internal {
 
         my $h    = $self->{_html} ||= HTML::Tiny->new;
         my $qs   = $h->url_decode( $query );
-        my $args = jsonToObj( $qs );
+        my $args = from_json( $qs );
 
         my $method = delete $args->{m}
           || die "Missing 'm' arg";
@@ -158,7 +158,7 @@ sub _despatch_internal {
         return HTTP::Response->new(
             200, 'OK',
             [ 'content_type' => 'application/json' ],
-            objToJson( [$result] )
+            to_json( [$result] )
         );
     };
 
